package de.communardo.confluence.plugins.addlink.v2;

import java.util.List;

import org.apache.log4j.Logger;

import de.communardo.confluence.plugins.configuration.ConfigurationAction;
import de.communardo.confluence.plugins.util.LinkHelper;
import de.communardo.confluence.plugins.util.LinkTreeHelper;

public class CreateEditLinkAction extends ConfigurationAction {

    /** Logger. */
    private static final Logger LOGGER = Logger.getLogger(CreateEditLinkAction.class);

    private static final long serialVersionUID = -2340651105317042863L;

    private String id;

    private String alias;

    private String target;

    public String doCreate() {

        List<Link> linkTree = linkTreeService.getLinkTree();

        Link link;
        try {
            link = LinkFactory.createLink(alias, target, linkTree);
        } catch (LinkCreationException e) {
            LOGGER.error(e.getMessage(), e);
            return ERROR;
        }

        linkTree.add(link);

        linkTreeService.storeLinkTree(linkTree);

        return SUCCESS;
    }

    public String doEdit() {

        if (id == null) {
            addActionError("");
            return ERROR;
        }

        List<Link> linkTree = linkTreeService.getLinkTree();

        Link link = LinkTreeHelper.getLink(linkTree, id);

        if (link == null) {
            addActionError("");
            return ERROR;
        }

        link.setAlias(alias);
        link.setTarget(target);

        LinkTreeHelper.editLink(linkTree, link);

        linkTreeService.storeLinkTree(linkTree);

        return SUCCESS;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void validate() {
        setUp();
        String postfix = "";

        if (id != null) {
            postfix = "_" + id;
        }

        if (alias == null || alias.trim().length() == 0) {
            addFieldError("link_alias" + postfix, getText("link.error.alias.empty"));
        }
        if (target == null || target.trim().length() == 0) {
            addFieldError("link_target" + postfix, getText("link.error.adress.empty"));
        } else if (!target.matches(LinkHelper.LINK_TARGET_REGEX)) {
            addFieldError("link_target" + postfix, getText("link.error.adress.protocol"));
        }
    }

    public void setTarget(String target) {
        this.target = target;
    }

    public void setAlias(String alias) {
        this.alias = alias;
    }

    public void setId(String id) {
        this.id = id;
    }

}
