package de.communardo.confluence.plugins.addlink.v2;

import java.util.ArrayList;
import java.util.List;
import java.util.UUID;

import de.communardo.confluence.plugins.util.LinkHelper;
import de.communardo.confluence.plugins.util.LinkTreeHelper;

public class LinkFactory {

    public static Link createLink(String alias, String target, List<Link> linkTree)
            throws LinkCreationException {
        if (alias == null || alias.trim().length() == 0) {
            throw new LinkCreationException("Can not create link because alias is empty.");
        }
        if (target == null || target.trim().length() == 0) {
            throw new LinkCreationException("Can not create link because target is empty.");
        } else if (!target.matches(LinkHelper.LINK_TARGET_REGEX)) {
            throw new LinkCreationException("Can not create link because target is not valid.");
        }
        try {
            return new Link(generateUniqueLinkId(linkTree), alias, target, new ArrayList<Link>());
        } catch (Exception e) {
            throw new LinkCreationException(
                    "Can not create link because could not get a unique identifier for link.");
        }
    }


    private static String generateUniqueLinkId(List<Link> linkTree) throws Exception {
        String id = String.valueOf(UUID.randomUUID().hashCode());
        int count = 0;
        // paranoia: we stop generating new ids after 1000 hash collisions (or 1000 times getting
        // the same UUID)
        while (count < 1000) {
            if (LinkTreeHelper.getLink(linkTree,id) == null) {
                return id;
            }
            id = String.valueOf(UUID.randomUUID().hashCode());
            count++;
        }

        throw new Exception("Could not create unique id. Possible cause: Problem with SecureRandom.");

    }

}
