package de.communardo.confluence.plugins.displaysubspace;

import java.util.Collection;
import java.util.List;
import java.util.Map;

import com.atlassian.confluence.renderer.PageContext;
import com.atlassian.confluence.renderer.radeox.macros.MacroUtils;
import com.atlassian.confluence.spaces.SpaceType;
import com.atlassian.confluence.user.AuthenticatedUserThreadLocal;
import com.atlassian.confluence.util.velocity.VelocityUtils;
import com.atlassian.renderer.RenderContext;
import com.atlassian.renderer.v2.RenderMode;
import com.atlassian.renderer.v2.macro.BaseMacro;
import com.atlassian.renderer.v2.macro.MacroException;
import com.atlassian.user.User;

import de.communardo.confluence.plugins.util.ComponentManager;

public class SubSpaceBreadCrumbsMacro extends BaseMacro {

    private static final String PARAMETER_CURRENTSPACE = "currentSpace";

    public String execute(Map parameters, String body, RenderContext renderContext)
            throws MacroException {

        Map<String, Object> velocityContext = MacroUtils.defaultVelocityContext();

        User user = AuthenticatedUserThreadLocal.getUser();
        // get the permitted Spaces... possible reason for performance las... use this method
        // carefully
        List permittedSpaces = ComponentManager.getSpaceManager().getPermittedSpaces(user);

        HierarchyBuilder hierarchyBuilder = new HierarchyBuilder(ComponentManager.getSpaceManager()
                .getSpacesByType(SpaceType.GLOBAL), TreeNodeComparator.TITLE);
        hierarchyBuilder.init(permittedSpaces);
        String currentSpace = (String) parameters.get(PARAMETER_CURRENTSPACE);
        if (currentSpace == null) {
            if (renderContext != null && renderContext instanceof PageContext
                    && ((PageContext) renderContext).getEntity() != null) {
                long pageId = ((PageContext) renderContext).getEntity().getId();
                currentSpace = ComponentManager.getSpaceManager().getSpaceFromPageId(pageId);
            }
        }
        velocityContext.put(PARAMETER_CURRENTSPACE, currentSpace);

        TreeNode treeNode = hierarchyBuilder.getNodeFromKey(currentSpace);
        if (treeNode != null) {
            Collection<TreeNode> path = treeNode.getPath();
            velocityContext.put("subspaceBreadcrumbs", path);
            return VelocityUtils.getRenderedTemplate(
                    "communardo_plugins/subspace_breadcrumbs/breadcrumbs.vm", velocityContext);
        }
        return "";
    }

    public RenderMode getBodyRenderMode() {
        return RenderMode.NO_RENDER;
    }

    public boolean hasBody() {
        return false;
    }

    @Override
    public boolean isInline() {
        return false;
    }

}
