package de.communardo.confluence.plugins.displaysubspace;

import java.util.ArrayList;
import java.util.Collection;
import java.util.SortedSet;
import java.util.TreeSet;

import com.atlassian.confluence.spaces.Space;

/**
 * 
 * 
 * @author Bill Martin
 * 
 */
public class TreeNode {

    private Space space;
    private Collection<TreeNode> children;
    private TreeNode parentNode;

    /**
     * 
     * @param space
     * @param comparator
     *            Same comparator like SpaceHierarchy
     */
    public TreeNode(Space space, TreeNodeComparator comparator) {
        this(space, comparator, null);
    }

    public TreeNode(Space space, TreeNodeComparator comparator, TreeNode parent) {
        this.space = space;
        this.children = new TreeSet<TreeNode>(comparator);
        this.parentNode = parent;
    }

    public TreeNode getParentNode() {
        return parentNode;
    }

    public boolean hasParentNode() {
        return parentNode != null;
    }

    public void setParentNode(TreeNode node) {
        parentNode = node;
    }

    /**
     * 
     * @return children The children.
     */
    public Collection<TreeNode> getChildren() {
        return children;
    }

    /**
     * 
     * @param children
     */
    public void setChildren(SortedSet<TreeNode> children) {
        this.children = children;
    }

    /**
     * 
     * @param space
     */
    public void setSpace(Space space) {
        this.space = space;
    }

    /**
     * 
     * @return space The space.
     */
    public Space getSpace() {
        return space;
    }

    public int getNodeLevel() {

        if (this.parentNode != null) {
            return this.parentNode.getNodeLevel() + 1;
        } else {
            return 0;
        }
    }

    public Collection<TreeNode> getPath() {
        Collection<TreeNode> path = new ArrayList<TreeNode>();
        if (this.parentNode != null) {
            path = this.parentNode.getPath();
        }
        path.add(this);
        return path;
    }

    @Override
    public String toString() {
        return space.getKey();
    }
}
