package de.communardo.confluence.plugins.webitem;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.log4j.Logger;

import com.atlassian.confluence.renderer.radeox.macros.MacroUtils;
import com.atlassian.confluence.util.velocity.VelocityUtils;
import com.atlassian.confluence.xhtml.api.XhtmlContent;
import com.atlassian.plugin.PluginParseException;
import com.atlassian.plugin.web.ContextProvider;

import de.communardo.confluence.plugins.configuration.SubspaceConfigurationService;

public class WebItemContextProvider implements ContextProvider {

    private XhtmlContent xhtmlContent;
    private static final Logger LOGGER = Logger.getLogger(WebItemContextProvider.class);
    private static final String REQUEST_ATTRIBUTE_SUBSPACE_PARSED_TEMPLATE_CODE = "subspace-parsed-template-code";
    private SubspaceConfigurationService subspaceConfigurationService;

    public Map<String, Object> getContextMap(Map<String, Object> contextMap) {

        Map<String, Object> returnContextMap = new HashMap<String, Object>(contextMap);
        returnContextMap.putAll(MacroUtils.defaultVelocityContext());
        HttpServletRequest requestFromContextMap = getRequestFromContextMap(returnContextMap);
        if (requestFromContextMap != null) {

            String servletPath = ((HttpServletRequest) requestFromContextMap).getServletPath();
            if (servletPath != null && (servletPath.startsWith("/admin") || servletPath.startsWith("/login"))) {
                return returnContextMap;
            }
        }

        returnContextMap.put("globalnav-active", subspaceConfigurationService.isGlobalNavigationBarActive());
        returnContextMap.put("breadcrumbs-active", subspaceConfigurationService.isBreadcrumbsActive());

        String parsedTemplatecode = (String) requestFromContextMap
                .getAttribute(REQUEST_ATTRIBUTE_SUBSPACE_PARSED_TEMPLATE_CODE);
        if (parsedTemplatecode == null) {
            parsedTemplatecode = "";

            try {
                parsedTemplatecode = VelocityUtils.getRenderedTemplate(
                        "communardo_plugins/dynamic_content/subspace-configuration.vm", returnContextMap);
            } catch (Throwable e) {
                String message = "Error during template resource parsing!";
                parsedTemplatecode = message;
                LOGGER.error(message, e);
            }

            requestFromContextMap.setAttribute(REQUEST_ATTRIBUTE_SUBSPACE_PARSED_TEMPLATE_CODE, parsedTemplatecode);
        }

        returnContextMap.put(REQUEST_ATTRIBUTE_SUBSPACE_PARSED_TEMPLATE_CODE, parsedTemplatecode);

        return returnContextMap;
    }

    private HttpServletRequest getRequestFromContextMap(Map<String, Object> contextMap) {
        return (HttpServletRequest) (contextMap.get("req") != null ? contextMap.get("req") : contextMap.get("request"));
    }

    public void init(Map<String, String> arg0) throws PluginParseException {
        // TODO Auto-generated method stub

    }

    public void setXhtmlContent(XhtmlContent xhtmlContent) {
        this.xhtmlContent = xhtmlContent;
    }

    public void setSubspaceConfigurationService(SubspaceConfigurationService subspaceConfigurationService) {
        this.subspaceConfigurationService = subspaceConfigurationService;
    }

}
